@@ -1,12 +1,25 @@
 package Osgood::EventList;
 use Moose;
+use MooseX::AttributeHelpers;
 use MooseX::Iterator;
+use MooseX::Storage;
 
-has 'events' => ( is => 'rw', isa => 'ArrayRef', default => sub { [] } );
+with Storage('format' => 'JSON', 'io' => 'File');
+
+has 'events' => (
+    metaclass => 'Collection::Array',
+    is => 'rw',
+    isa => 'ArrayRef',
+    default => sub { [] },
+    provides => {
+        push => 'add_to_events',
+        count => 'size'
+    }
+);
 
 has 'iterator' => (
-	metaclass => 'Iterable',
-	iterate_over => 'events'
+    metaclass => 'Iterable',
+    iterate_over => 'events'
 );
 
 =head1 NAME
@@ -19,58 +32,35 @@ A list of events.
 
 =head1 SYNOPSIS
 
-  my $list = new Osgood::EventList();
+  my $list = Osgood::EventList->new;
   $list->add_to_events($event);
-  print $list->size()."\n";
+  print $list->size."\n";
 
 =head1 METHODS
 
 =head2 Constructor
 
-=over 4
-
-=item new
+=head2 new
 
 Creates a new Osgood::EventList object.
 
-=back
-
-=head2 Class Methods
-
-=over 4
-
-=item add_to_events
+=head2 add_to_events
 
 Add the specified event to the list.
 
-=cut
-sub add_to_events {
-	my $self = shift();
-	my $event = shift();
-
-	push(@{ $self->events() }, $event);
-}
-
-=item events
+=head2 events
 
 Set/Get the ArrayRef of events in this list.
 
-=item iterator
+=head2 iterator
 
 Returns a MooseX::Iterator for iterating over events.
 
-=item size
+=head2 size
 
 Returns the number of events in this list.
 
-=cut
-sub size {
-	my $self = shift();
-
-	return scalar(@{ $self->events });
-}
-
-=item get_highest_id
+=head2 get_highest_id
 
 Retrieves the largest id from the list of events.  This is useful for keeping
 state with an external process that needs to 'remember' the last event id
@@ -78,12 +68,12 @@ it handled.
 
 =cut
 sub get_highest_id {
-	my $self = shift();
+	my ($self) = @_;
 
 	my $high = undef;
-	foreach my $event (@{ $self->events() }) {
-		if(!defined($high) || ($high < $event->id())) {
-			$high = $event->id();
+	foreach my $event (@{ $self->events }) {
+		if(!defined($high) || ($high < $event->id)) {
+			$high = $event->id;
 		}
 	}
 
@@ -100,11 +90,13 @@ perl(1), L<Osgood::Event>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 by Magazines.com, LLC
+Copyright 2008-2009 by Magazines.com, LLC
 
 You can redistribute and/or modify this code under the same terms as Perl
 itself.
 
 =cut
 
+__PACKAGE__->meta->make_immutable;
+
 1;
\ No newline at end of file
